/* server.h - The G13 Assuan server
 * Copyright (C) 2009 Free Software Foundation, Inc.
 *
 * This file is part of GnuPG.
 *
 * GnuPG is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * GnuPG is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef G13_SERVER_H
#define G13_SERVER_H


gpg_error_t g13_server (ctrl_t ctrl);

gpg_error_t g13_proxy_pinentry_notify (ctrl_t ctrl, const unsigned char *line);

gpg_error_t g13_keyblob_decrypt (ctrl_t ctrl,
                                 const void *enckeyblob, size_t enckeybloblen,
                                 void **r_keyblob, size_t *r_keybloblen);

#endif /*G13_SERVER_H*/
